@@ -13,7 +13,7 @@ use Test::Builder;
 use File::Find;
 use Scalar::Util qw(blessed);
 
-our $VERSION = '1.38_01';
+our $VERSION = '1.38_02';
 our $VERBOSE = 1;
 our $HOME;
 our $test_bool = 1;
@@ -234,7 +234,7 @@ sub _check_manifest {
         $success = $bool == $test_bool;
     }
 
-    $test->diag($diag) if %missing_files     >= 1 and $test_bool == 1 and $VERBOSE;
+    $test->diag($diag) if keys %missing_files     >= 1 and $test_bool == 1 and $VERBOSE;
     $test->diag($plus) if scalar @files_plus >= 1 and $test_bool == 1 and $VERBOSE;
     $test->diag($dup)  if scalar @dup_files  >= 1 and $test_bool == 1 and $VERBOSE;
 
@@ -372,7 +372,7 @@ Test::CheckManifest - Check if your Manifest matches your distro
 
 =head1 VERSION
 
-version 1.38_01
+version 1.38_02
 
 =head1 SYNOPSIS
 
